;****************************************************************************
; PIC14000 Header
;       Copyright 1995, 1998 microEngineering Labs, Inc.
;****************************************************************************

					; *** Default Device Specifications
		DEVICE  3FFF3FFFh       ; All Fuse Bits On
		DEVICE  50080003h       ; 14-Bit, 4K Code, 0 EE, ID = 3

					; *** DEVICE Device Definitions
PIC14000        equ     50080003h       ; 14-Bit, 4K Code, 0 EE, ID = 3

					; *** DEVICE Fuses Definitions
RC_OSC          equ     3FFE0001h       ; XX XXXX XXXX XXX1
HS_OSC          equ     3FFE0000h       ; XX XXXX XXXX XXX0
WDT_ON          equ     3FFB0004h       ; XX XXXX XXXX X1XX
WDT_OFF         equ     3FFB0000h       ; XX XXXX XXXX X0XX
PWRT_OFF        equ     3FF70008h       ; XX XXXX XXXX 1XXX
PWRT_ON         equ     3FF70000h       ; XX XXXX XXXX 0XXX
PROTECT_OFF     equ     004F3FB0h       ; 11 1111 1X11 XXXX
PROTECT_ON      equ     004F0000h       ; 00 0000 0X00 XXXX

					; *** Register Names
INDF            equ     00h             ; Indirect Data
TMR0            equ     01h             ; Real Time Clock/Counter
PCL             equ     02h             ; Program Counter (LSB)
STATUS          equ     03h             ; Status Flags
FSR             equ     04h             ; File Select Register
PORTA           equ     05h             ; Port A Data
RA              equ     05h
PORTC           equ     07h             ; Port C Data
RC              equ     07h
PORTD           equ     08h             ; Port D Data
RD              equ     08h
PCLATH          equ     0Ah             ; Program Counter (MSB)
INTCON          equ     0Bh             ; Interrupt Control
PIR1            equ     0Ch             : Peripheral Interrupt Flags 1
ADTMRL          equ     0Eh             ; A/D Capture Timer Data (LSB)
ADTMRH          equ     0Fh             ; A/D Capture Timer Data (MSB)
I2CBUF          equ     13h             ; I2C Data
I2CCON          equ     14h             ; I2C Control
ADCAPL          equ     15h             ; A/D Capture Latch (LSB)
ADCAPH          equ     16h             ; A/D Capture Latch (MSB)
ADCON0          equ     1Fh             ; A/D Control 0
OPTION_REG      equ     81h             ; OPTION Register
TRISA           equ     85h             ; Port A Tristate Control
TRISC           equ     87h             ; Port C Tristate Control
TRISD           equ     88h             ; Port D Tristate Control
PIE1            equ     8Ch             ; Peripheral Interrupt Enables 1
PCON            equ     8Eh             ; Power Control
SLPCON          equ     8Fh             ; Sleep Control
I2CADD          equ     93h             ; I2C Address
I2CSTAT         equ     94h             ; I2C Status Flags
LDACA           equ     9Bh             ;
LDACB           equ     9Ch             ;
CHGCON          equ     9Dh             ;
MISC            equ     9Eh             ;
ADCON1          equ     9Fh             ; A/D Control 1

					; *** STATUS Bits
C               equ     0               ; Carry
DC              equ     1               ; Digit (Half) Carry
Z               equ     2               ; Zero
PD              equ     3               ; Power Down
TO              equ     4               ; Time Out
RP0             equ     5               ; Direct Data Page Select 0
RP1             equ     6               ; Direct Data Page Select 1
IRP             equ     7               ; Indirect Data Page Select

					; *** INTCON Bits
T0IF            equ     2               ; TMR0 Overflow Interrupt Flag
T0IE            equ     5               ; TMR0 Overflow Interrupt Enable
PEIE            equ     6               ; Peripheral Interrupt Enable
GIE             equ     7               ; Global Interrupt Enable

					; *** PIR1 Bits
OVFIF           equ     0               ; A/D Counter Overflow Interrupt Flag
ADCIF           equ     1               ; A/D Conversion Complete Capture Interrupt Flag
RCIF            equ     2               ; Port C Interrupt On Change Flag
I2CIF           equ     3               ; I2C Port Interrupt Flag
PBIF            equ     4               ; External Push Button Interrupt Flag
WUIF            equ     7               ; Wake-up On Current Flow Interrupt Flag

                                        ; *** I2CCON Bits
I2CM0           equ     0               ; I2C Mode Select (4 Bits)
I2CM1           equ     1
I2CM2           equ     2
I2CM3           equ     3
CKP             equ     4               ; Clock Polarity Select
I2CEN           equ     5               ; I2C Enable
I2COV           equ     6               ; I2C Receive Overflow Flag
WCOL            equ     7               ; Write Collision Detect

					; *** ADCON0 Bits
ADZERO          equ     0               ; A/D Zero Select Control
ADRST           equ     1               ; A/D Reset Control Bit
AMUXOE          equ     2               ; Analog Mux Output Enable
ADCS0           equ     4               ; A/D Channel Select (4 Bits)
ADCS1           equ     5
ADCS2           equ     6
ADCS3           equ     7

					; *** OPTION Bits
PS0             equ     0               ; Prescaler Divisor Select (3 Bits)
PS1             equ     1
PS2             equ     2
PSA             equ     3               ; Prescaler Assignment
T0SE            equ     4               ; Timer0 Source Edge Select
T0CS            equ     5               ; Timer0 Clock Source Select
RCPU            equ     7               ; Port C Pull-Up Enable

					; *** PIE1 Bits
OVFIE           equ     0               ; A/D Counter Overflow Interrupt Enable
ADCIE           equ     1               ; A/D Conversion Complete Capture Interrupt Enable
RCIE            equ     2               ; Port C Interrupt On Change Enable
I2CIE           equ     3               ; I2C Port Interrupt Enable
PBIE            equ     4               ; External Push Button Interrupt Enable
WUIE            equ     7               ; Wake-up On Current Flow Interrupt Enable

					; *** PCON Bits
LVD             equ     0               ; Low Voltage Detect Flag
POR             equ     1               ; Power-On Reset Flag

                                        ; *** SLPCON Bits
ADOFF           equ     0               ; A/D Module Power Control
TEMPOFF         equ     1               ; On-chip Temperature Sensor Power Control
CWUOFF          equ     2               ; Charge Controller/Current Flow Detect Power Control
OSCOFF          equ     3               ; Internal Oscillator On/Off During Sleep Mode
BIASOFF         equ     4               ; Summing Junction Current Bias Source Power Control
REFOFF          equ     5               ; References Power Control
HIBEN           equ     7               ; Hibernate Mode Select

                                        ; *** I2CSTAT Bits
BF              equ     0               ; I2C Buffer Full Flag
UA              equ     1               ; I2C Update Address Flag
R_W             equ     2               ; I2C Read/Write Status
S               equ     3               ; I2C Start Flag
P               equ     4               ; I2C Stop Flag
D_A             equ     5               ; I2C Data/Address Flag

                                        ; *** LDACA Bits
LDASEL0         equ     0               ; DAC A Voltage Select Bits (8 Bits)
LDASEL1         equ     1
LDASEL2         equ     2
LDASEL3         equ     3
LDASEL4         equ     4
LDASEL5         equ     5
LDASEL6         equ     6
LDASEL7         equ     7

                                        ; *** LDACB Bits
LDBSEL0         equ     0               ; DAC B Voltage Select Bits (8 Bits)
LDBSEL1         equ     1
LDBSEL2         equ     2
LDBSEL3         equ     3
LDBSEL4         equ     4
LDBSEL5         equ     5
LDBSEL6         equ     6
LDBSEL7         equ     7

                                        ; *** CHGCON Bits
CPOLA           equ     0               ; Charge Control Polarity Bit A
CCAEN           equ     1               ; Charge Control Function Enable Bit A
CCOMPA          equ     2               ; Charge Control Comparator Output A
CPOLB           equ     4               ; Charge Control Polarity Bit B
CCBEN           equ     5               ; Charge Control Function Enable Bit B
CCOMPB          equ     6               ; Charge Control Comparator Output B

                                        ; *** MISC Bits
OSC1            equ     0               ; OSC1 Input Port Bit
OSC2            equ     1               ; OSC2 Input Port Bit
INCLKEN         equ     2               ; Oscillator Output Select
SMBUS           equ     3               ; SMBus-Compatibility Select
I2CSEL          equ     4               ; I2C Port Select Bit
SPGNDA          equ     5               ; Serial Port Ground Select
SPGNDB          equ     6               ; Serial Port Ground Select
SMHOG           equ     7               ; SMHOG Enable

					; *** ADCON1 Bits
ACFG0           equ     0               ; Port A Configuration Selects (2 Bits)
ACFG1           equ     1
ACFG2           equ     2               ; Port D Configuration Selects (2 Bits)
PCFG3           equ     3
ADDAC0          equ     4               ; A/D Current DAC Selects (4 Bits)
ADDAC1          equ     5
ADDAC2          equ     6
ADDAC3          equ     7
